# position vector
# other variables
from ..Classes.EntityLayer import EntityLayer

x = 221
y = 128
otherVar = ["circle", 24]
variableObject = EntityLayer((0, 0), otherVar, 0, "", (x, y))
print(variableObject.getOtherVariables() + variableObject.getPositionVector())



# water engine
from saruca_uuv.sensing_system_layer.Methods.variables import EntityLayer


def behaviour():
    entity = EntityLayer([0, 0], "circle", 40, [8, "", 8], (2, 3))
    return entity.getPositionVector()



"""
    engine breakdown
"""


from saruca_uuv.sensing_system_layer.Methods.variables import EntityLayer


def engineBreakdown():
    entity = EntityLayer([0, 0], "circle", 40, [8, "", 8], (2, 3))
    if entity.getOtherVariables() == ["", 1]:
        return 1
    else:
        return 0



# assignment
# behaviour
# orbit
# command
"""
from ..Methods.assignment import assignment
from ..Methods.orbit import orbit
from ..Methods.command import command
from ..Methods.behaviour import behaviour
from ..Methods.engineBreakdown import engineBreakdown
"""


class ControlLayer:
    __assignment = ""
    __orbit = ""
    __command = ["", 5]
    __behaviour = ""
    __engineBreakdown = 0

    def __int__(self,
                assignment=None,
                orbit=None,
                command=None,
                behaviour=None,
                engineBreakdown=None):
        if assignment is None:
            self.__assignment = ""
        else:
            self.__assignment = assignment
        if orbit is None:
            self.__orbit = ""
        else:
            self.__orbit = orbit
        if command is None:
            self.__command = ["", 5]
        else:
            for __command in command:
                self.__command = command
        if behaviour is None:
            self.__behaviour = ""
        else:
            self.__behaviour = behaviour
        if engineBreakdown is None:
            self.__engineBreakdown = 0
        else:
            self.__engineBreakdown = engineBreakdown

    def getAssignment(self):
        return self.__assignment

    def getOrbit(self):
        return self.__orbit

    def getCommand(self):
        return self.__command

    def getBehaviour(self):
        return self.__behaviour

    def getEngineBreakdown(self):
        return self.__engineBreakdown



# orbital redirection

from saruca_uuv.sensing_system_layer.Methods.variables import EntityLayer


def orbit():
    entity = EntityLayer([0, 0], "circle", 40, [8, "", 8], (2, 3))
    if entity.getPositionVector() == (2, 3):
        return "forward/backward"
    else:
        return "right/left"
